"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var color_1 = require("./color");
var blessed = require('blessed');
var contrib = require('blessed-contrib');
var WidgetRender = (function () {
    function WidgetRender() {
    }
    WidgetRender.form = function (title) {
        return blessed.screen({ smartCSR: true, fullUnicode: true, autoPadding: true, title: title });
    };
    WidgetRender.menuBar = function (parent, commands) {
        var bar = blessed.listbar({
            parent: parent,
            top: 0,
            left: 0,
            right: 0,
            height: 'shrink',
            mouse: true,
            keys: true,
            autoCommandKeys: true,
            border: 'line',
            style: {
                item: { bg: color_1.Color.yellow, fg: color_1.Color.black, hover: { bg: color_1.Color.blue } },
                selected: { bg: color_1.Color.blue }
            },
            commands: commands
        });
        bar.focus();
        return bar;
    };
    WidgetRender.table = function (parent, top, left, width, height, label) {
        return blessed.listtable({
            parent: parent,
            top: top,
            left: left,
            border: 'line',
            align: 'left',
            tags: true,
            keys: true,
            width: width,
            height: height,
            mouse: true,
            style: {
                fg: color_1.Color.white,
                header: { fg: color_1.Color.blue, bold: true },
                border: { fg: color_1.Color.black },
                cell: { fg: color_1.Color.magenta, selected: { bg: color_1.Color.blue } }
            },
            label: label
        });
    };
    ;
    WidgetRender.box = function (parent) {
        return blessed.box({
            parent: parent,
            align: 'center',
            scrollable: true,
            scrollstep: 1,
            left: 0,
            top: 2,
            width: '100%',
            height: 'shrink',
            border: 'line',
            alwaysScroll: false,
            scrollbar: {
                ch: ' '
            }
        });
    };
    WidgetRender.text = function (parent, top, left, width, heigth, content) {
        return blessed.text({
            parent: parent,
            top: top,
            left: left,
            tags: true,
            keys: true,
            width: width,
            height: heigth,
            content: content
        });
    };
    ;
    WidgetRender.line = function (opts, width, height, color, label, showLegend, legendWidth) {
        if (showLegend === void 0) { showLegend = false; }
        if (legendWidth === void 0) { legendWidth = 4; }
        return new contrib.line({
            top: opts.top,
            left: opts.left,
            right: opts.right,
            bottom: opts.bottom,
            width: width,
            height: height,
            style: {
                line: color,
                text: 'green',
                baseline: ['#696969']
            },
            border: {
                type: "line",
                fg: "cyan"
            },
            showNthLabel: 1,
            label: ' ' + label + ' ',
            xLabelPadding: 3,
            showLegend: showLegend,
            legend: {
                width: legendWidth
            },
        });
    };
    ;
    WidgetRender.inspectBox = function (parent, right, bottom, width, height, label) {
        return blessed.box({
            parent: parent,
            label: label,
            scrollable: true,
            scrollstep: 1,
            right: right,
            bottom: bottom,
            width: width,
            height: height,
            align: 'left',
            style: { fg: color_1.Color.blue },
            border: { type: 'line', fg: color_1.Color.cyan },
            content: '',
            keys: true,
            mouse: true,
            alwaysScroll: true,
            scrollbar: {
                ch: ' ',
                inverse: true
            }
        });
    };
    ;
    WidgetRender.helpBox = function (parent, content) {
        return blessed.box({
            parent: parent,
            label: ' Help ',
            scrollable: true,
            scrollstep: 1,
            left: 'center',
            top: 'center',
            width: '60%',
            height: 24,
            align: 'left',
            style: {
                bg: 'black'
            },
            border: {
                type: "line",
                fg: "cyan"
            },
            content: content,
            keys: true,
            mouse: true,
            vi: true,
            alwaysScroll: true,
            scrollbar: {
                ch: ' ',
                inverse: true
            }
        });
    };
    return WidgetRender;
}());
exports.WidgetRender = WidgetRender;
